@@ -21,7 +21,7 @@ while(<IN>) {
 	if(!$mode && /^xkb_symbols\s+\"([^\"]+)/ && $layouts{$1}) {
 		open(CONF, "<$layouts{$1}") or die "Can't open for read $layouts{$1} file\n";
 		chomp($_ = <CONF>);
-		print OUT "xkb_symbols \"$1\" {\n  name[Group1] = \"$_\";\n\n";
+		print OUT "partial alphanumeric_keys\nxkb_symbols \"$1\" {\n  name[Group1] = \"$_\";\n\n";
 		foreach my $s(split/\s+/, <CONF>) { print OUT "  include \"nokia_vndr/rx-51($s)\"\n"; }
 		print OUT "\n  key.type[Group1] = \"EIGHT_LEVEL_SEMIALPHABETIC\";\n\n";
 		while(<CONF>) {
